| define_water_once | R Documentation |
define_water and output a dataframeThis function allows define_water to be added to a piped data frame.
It outputs all carbonate calculations and other parameters in a data frame.
tidywater functions cannot be added after this function because they require a water class input.
define_water_once(df)
df |
a data frame containing columns with all the parameters listed in |
For large datasets, using fn_once or fn_chain may take many minutes to run. These types of functions use the furrr package
for the option to use parallel processing and speed things up. To initialize parallel processing, use
plan(multisession) or plan(multicore) (depending on your operating system) prior to your piped code with the
fn_once or fn_chain functions. Note, parallel processing is best used when your code block takes more than a minute to run,
shorter run times will not benefit from parallel processing.
A data frame containing columns that were filled or calculated based on define_water.
define_water
example_df <- water_df %>%
define_water_once()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.